@@ -22,6 +22,9 @@ private Q_SLOTS:
     void testReloadMultipleViews();
     void testTabCursorOnReload();
     void testLowerCaseBlockSelection();
+
+    void testEditorWidget();
+    void testCoordinatesToCursor_data();
     void testCoordinatesToCursor();
     void testCursorToCoordinates();
     void testSelection();
