@@ -324,81 +324,6 @@ void ViewTest::visualLineUpDownTests()
     kate_document->config()->setTabWidth(oldTabWidth);
 }
 
-void ViewTest::ScrollViewTests()
-{
-    QSKIP("This is too unstable in Jenkins", SkipAll);
-
-    // First of all, we have to initialize some sizes and fonts.
-    ensureKateViewVisible();
-
-    const QFont oldFont = kate_view->rendererConfig()->baseFont();
-    QFont fixedWidthFont(QStringLiteral("Monospace"));
-
-    fixedWidthFont.setStyleHint(QFont::TypeWriter);
-    fixedWidthFont.setPixelSize(14);
-    Q_ASSERT_X(QFontInfo(fixedWidthFont).fixedPitch(), "setting up ScrollViewTests", "Need a fixed pitch font!");
-    kate_view->rendererConfig()->setFont(fixedWidthFont);
-
-    // Generating our text here.
-    QString text;
-    for (int i = 0; i < 20; i++) {
-        text += QLatin1String("    aaaaaaaaaaaaaaaa\n");
-    }
-
-    // TODO: fix the visibleRange's tests.
-
-    // zz
-    BeginTest(text);
-    TestPressKey(QStringLiteral("10l9jzz"));
-    QCOMPARE(kate_view->cursorPosition().line(), 9);
-    QCOMPARE(kate_view->cursorPosition().column(), 10);
-    QCOMPARE(kate_view->visibleRange(), Range(4, 0, 13, 20));
-    FinishTest(text.toUtf8().constData());
-
-    // z.
-    BeginTest(text);
-    TestPressKey(QStringLiteral("10l9jz."));
-    QCOMPARE(kate_view->cursorPosition().line(), 9);
-    QCOMPARE(kate_view->cursorPosition().column(), 4);
-    QCOMPARE(kate_view->visibleRange(), Range(4, 0, 13, 20));
-    FinishTest(text.toUtf8().constData());
-
-    // zt
-    BeginTest(text);
-    TestPressKey(QStringLiteral("10l9jzt"));
-    QCOMPARE(kate_view->cursorPosition().line(), 9);
-    QCOMPARE(kate_view->cursorPosition().column(), 10);
-    QCOMPARE(kate_view->visibleRange(), Range(9, 0, 18, 20));
-    FinishTest(text.toUtf8().constData());
-
-    // z<cr>
-    BeginTest(text);
-    TestPressKey(QStringLiteral("10l9jz\\return"));
-    QCOMPARE(kate_view->cursorPosition().line(), 9);
-    QCOMPARE(kate_view->cursorPosition().column(), 4);
-    QCOMPARE(kate_view->visibleRange(), Range(9, 0, 18, 20));
-    FinishTest(text.toUtf8().constData());
-
-    // zb
-    BeginTest(text);
-    TestPressKey(QStringLiteral("10l9jzb"));
-    QCOMPARE(kate_view->cursorPosition().line(), 9);
-    QCOMPARE(kate_view->cursorPosition().column(), 10);
-    QCOMPARE(kate_view->visibleRange(), Range(0, 0, 9, 20));
-    FinishTest(text.toUtf8().constData());
-
-    // z-
-    BeginTest(text);
-    TestPressKey(QStringLiteral("10l9jz-"));
-    QCOMPARE(kate_view->cursorPosition().line(), 9);
-    QCOMPARE(kate_view->cursorPosition().column(), 4);
-    QCOMPARE(kate_view->visibleRange(), Range(0, 0, 9, 20));
-    FinishTest(text.toUtf8().constData());
-
-    // Restore back to how we were before.
-    kate_view->rendererConfig()->setFont(oldFont);
-}
-
 void ViewTest::clipboardTests_data()
 {
     QTest::addColumn<QString>("text");
