@@ -533,7 +533,11 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
     int openedRegionOffset = -1;
     {
         // mapping of type to "first" offset of it and current number of not matched openings
-        QHash<int, QPair<int, int>> foldingStartToOffsetAndCount;
+        struct OffsetAndCount {
+            int offset;
+            int count;
+        };
+        QHash<int, OffsetAndCount> foldingStartToOffsetAndCount;
 
         // walk over all attributes of the line and compute the matchings
         const auto startLineAttributes = computeFoldings(startLine);
@@ -543,8 +547,8 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
                 // search for this type, try to decrement counter, perhaps erase element!
                 auto end = foldingStartToOffsetAndCount.find(startLineAttributes[i].foldingRegion.id());
                 if (end != foldingStartToOffsetAndCount.end()) {
-                    if (end.value().second > 1) {
-                        --(end.value().second);
+                    if (end.value().count > 1) {
+                        --(end.value().count);
                     } else {
                         foldingStartToOffsetAndCount.erase(end);
                     }
@@ -556,20 +560,20 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
                 // search for this type, either insert it, with current offset or increment counter!
                 auto start = foldingStartToOffsetAndCount.find(startLineAttributes[i].foldingRegion.id());
                 if (start != foldingStartToOffsetAndCount.end()) {
-                    ++(start.value().second);
+                    ++(start.value().count);
                 } else {
-                    foldingStartToOffsetAndCount.insert(startLineAttributes[i].foldingRegion.id(), qMakePair(startLineAttributes[i].offset, 1));
+                    foldingStartToOffsetAndCount.insert(startLineAttributes[i].foldingRegion.id(), OffsetAndCount(startLineAttributes[i].offset, 1));
                 }
             }
         }
 
         // compute first type with offset
-        QHashIterator<int, QPair<int, int>> hashIt(foldingStartToOffsetAndCount);
+        QHashIterator<int, OffsetAndCount> hashIt(foldingStartToOffsetAndCount);
         while (hashIt.hasNext()) {
             hashIt.next();
-            if (openedRegionOffset == -1 || hashIt.value().first < openedRegionOffset) {
+            if (openedRegionOffset == -1 || hashIt.value().offset < openedRegionOffset) {
                 openedRegionType = hashIt.key();
-                openedRegionOffset = hashIt.value().first;
+                openedRegionOffset = hashIt.value().offset;
             }
         }
     }
@@ -614,4 +618,70 @@ KTextEditor::Range KateBuffer::computeFoldingRangeForStartLine(int startLine)
     return KTextEditor::Range(KTextEditor::Cursor(startLine, openedRegionOffset), KTextEditor::Cursor(lines() - 1, plainLine(lines() - 1).length()));
 }
 
+KTextEditor::Range
+KateBuffer::findMatchingFoldingMarker(const KTextEditor::Cursor currentCursorPos, const KSyntaxHighlighting::FoldingRegion foldingRegion, const int maxLines)
+{
+    auto getStartOffset = [](int direction, int offset, int length) {
+        return direction == 1 ? offset - length : offset;
+    };
+
+    auto getEndOffset = [](int direction, int offset, int length) {
+        return direction == 1 ? offset : offset + length;
+    };
+
+    const int direction = (foldingRegion.type() == KSyntaxHighlighting::FoldingRegion::Begin) ? 1 : -1;
+    int foldCounter = 0;
+    int lineCounter = 0;
+    const auto foldMarkers = computeFoldings(currentCursorPos.line());
+
+    // searching a end folding marker? go left to right
+    // otherwise, go right to left
+    long i = direction == 1 ? 0 : (long)foldMarkers.size() - 1;
+
+    // For the first line, we start considering the first folding after the cursor
+    for (; i >= 0 && i < (long)foldMarkers.size(); i += direction) {
+        if ((foldMarkers[i].offset - currentCursorPos.column()) * direction > 0 && foldMarkers[i].foldingRegion.id() == foldingRegion.id()) {
+            if (foldMarkers[i].foldingRegion.type() == foldingRegion.type()) {
+                foldCounter += 1;
+            } else if (foldCounter > 0) {
+                foldCounter -= 1;
+            } else if (foldCounter == 0) {
+                return KTextEditor::Range(currentCursorPos.line(),
+                                          getStartOffset(direction, foldMarkers[i].offset, foldMarkers[i].length),
+                                          currentCursorPos.line(),
+                                          getEndOffset(direction, foldMarkers[i].offset, foldMarkers[i].length));
+            }
+        }
+    }
+
+    // for the other lines
+    int currentLine = currentCursorPos.line() + direction;
+    for (; currentLine >= 0 && currentLine < lines() && lineCounter < maxLines; currentLine += direction) {
+        // update line attributes
+        const auto foldMarkers = computeFoldings(currentLine);
+        i = direction == 1 ? 0 : (long)foldMarkers.size() - 1;
+
+        // iterate through the markers
+        for (; i >= 0 && i < (long)foldMarkers.size(); i += direction) {
+            if (foldMarkers[i].foldingRegion.id() == foldingRegion.id()) {
+                if (foldMarkers[i].foldingRegion.type() == foldingRegion.type()) {
+                    foldCounter += 1;
+                } else if (foldCounter != 0) {
+                    foldCounter -= 1;
+                } else if (foldCounter == 0) {
+                    return KTextEditor::Range(currentLine,
+                                              getStartOffset(direction, foldMarkers[i].offset, foldMarkers[i].length),
+                                              currentLine,
+                                              getEndOffset(direction, foldMarkers[i].offset, foldMarkers[i].length));
+                }
+            }
+        }
+        lineCounter += 1;
+    }
+
+    // got out of loop, no matching folding found
+    // returns a invalid folding range
+    return KTextEditor::Range::invalid();
+}
+
 #include "moc_katebuffer.cpp"
